<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package spintech
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function spintech_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
	
	// Header Type
	$spintech_header_type	=	get_theme_mod('spintech_header_type','header-default header-nav-white');
	$classes[] = esc_attr($spintech_header_type);

	// Wide Boxed
	$wide_boxed=get_theme_mod('wide_boxed','wide');
	if($wide_boxed == "boxed") {
		$classes[] = 'boxed';
	} else {
		$classes[] = 'wide';
	}

	// Front Pallate Enable / Disable
	$front_pallate_enable = get_theme_mod('front_pallate_enable');
	if($front_pallate_enable == '1') {
		$classes[] = 'front_pallate_enable';
	}

	return $classes;
}
add_filter( 'body_class', 'spintech_body_classes' );

if ( ! function_exists( 'wp_body_open' ) ) {
	/**
	 * Backward compatibility for wp_body_open hook.
	 *
	 * @since 1.0.0
	 */
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
}

if (!function_exists('spintech_str_replace_assoc')) {

    /**
     * spintech_str_replace_assoc
     * @param  array $replace
     * @param  array $subject
     * @return array
     */
    function spintech_str_replace_assoc(array $replace, $subject) {
        return str_replace(array_keys($replace), array_values($replace), $subject);
    }
}

//Background Image Pattern
function spintech_background_pattern(){
	$bg_pattern = get_theme_mod('bg_pattern','bg-img1.png');
	if($bg_pattern!='')
	{
	echo '<style>body.boxed { background:url("'.get_template_directory_uri().'/assets/images/bg-pattern/'.$bg_pattern.'");}</style>';
	}
}
add_action('wp_head','spintech_background_pattern',10,0);




 /**
 * Add WooCommerce Cart Icon With Cart Count (https://isabelcastillo.com/woocommerce-cart-icon-count-theme-header)
 */
function spintech_add_to_cart_fragment( $fragments ) {
	
    ob_start();
    $count = WC()->cart->cart_contents_count;
	$header_cart				= get_theme_mod('header_cart','fa-shopping-cart'); 
    ?> 
	<div class="cart-count"><i class="fa fa-shopping-bag"></i>
	<?php
    if ( $count > 0 ) { 
	?>
        <span><?php echo esc_html( $count ); ?></span>
	<?php            
    } else {
	?>	
		<span>0</span>
	<?php
	}
    ?></div><?php
 
    $fragments['.cart-count'] = ob_get_clean();
     
    return $fragments;
}
add_filter( 'woocommerce_add_to_cart_fragments', 'spintech_add_to_cart_fragment' );




// Activate WordPress Maintenance Mode
$enable_comming_soon = get_theme_mod('enable_comming_soon');
if($enable_comming_soon == '1') { 
	function wp_maintenance_mode() {
		if (!current_user_can('edit_themes') || !is_user_logged_in()) {
		   // wp_die('<h1>Under Maintenance</h1><br />Something aint right, but we are working on it! Check back later.');
		   $file = get_template_directory() . '/inc/maintenance.php';
				include($file);
				exit();
		}
	}
	add_action('get_header', 'wp_maintenance_mode');
}

/*
 *
 * Social Icon
 */
function spintech_get_social_icon_default() {
	return apply_filters(
		'spintech_get_social_icon_default', json_encode(
				 array(
				array(
					'icon_value'	  =>  esc_html__( 'fa-facebook', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_header_social_001',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-twitter', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_header_social_003',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-instagram', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_header_social_004',
				),
			)
		)
	);
}



/*
 *
 * Footer Social Icon
 */
function spintech_get_footer_social_icon_default() {
	return apply_filters(
		'spintech_get_footer_social_icon_default', json_encode(
				 array(
				array(
					'icon_value'	  =>  esc_html__( 'fa-facebook', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_footer_social_001',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-twitter', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_footer_social_002',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-google-plus', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_footer_social_003',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-pinterest', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_footer_social_004',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-instagram', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_footer_social_005',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-dribbble', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_footer_social_006',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-linkedin', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_footer_social_007',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-skype', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_footer_social_008',
				),
			)
		)
	);
}



/*
 *
 * Footer Contact Info
 */
 function spintech_get_foot_info_default() {
	return apply_filters(
		'spintech_get_foot_info_default', json_encode(
				 array(
				array(
					'title'           => esc_html__( 'Online 24/7', 'spintech-pro' ),
					'text'            => esc_html__( '70 975 975 70', 'spintech-pro' ),
					'icon_value'       => 'fa-comments',
					'id'              => 'customizer_repeater_foot_info_001',
					
				),
				array(
					'title'           => esc_html__( 'Send Us Email', 'spintech-pro' ),
					'text'            => esc_html__( 'Info@example.com', 'spintech-pro' ),
					'icon_value'       => 'fa-envelope',
					'id'              => 'customizer_repeater_foot_info_002',			
				),
			)
		)
	);
}


/*
 *
 * Slider Default
 */
 function spintech_get_slider_default() {
	return apply_filters(
		'spintech_get_slider_default', json_encode(
				 array(
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/slider/img01.jpg',
					'title'           => esc_html__( 'New Skills', 'spintech-pro' ),
					'subtitle'         => esc_html__( 'Best Choice For Your Business', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor labore', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Purchase Now', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'button_second'	  =>  esc_html__( 'Learn More', 'spintech-pro' ),
					'link2'	  =>  esc_html__( '#', 'spintech-pro' ),
					'btn_lbl3'	  =>  esc_html__( 'Watch Video', 'spintech-pro' ),
					"slide_align" => "left", 
					'id'              => 'customizer_repeater_slider_001',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/slider/img02.jpg',
					'title'           => esc_html__( 'Develop Stronger Minds', 'spintech-pro' ),
					'subtitle'         => esc_html__( 'Better Coaching Gets', 'spintech-pro' ),
					'text'            => esc_html__( 'There are many variations of passages of Lorem Ipsum available but the majority have suffered injected humour dummy now.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Purchase Now', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'button_second'	  =>  esc_html__( 'Learn More', 'spintech-pro' ),
					'link2'	  =>  esc_html__( '#', 'spintech-pro' ),
					'btn_lbl3'	  =>  esc_html__( 'Watch Video', 'spintech-pro' ),
					"slide_align" => "center", 
					'id'              => 'customizer_repeater_slider_002',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/slider/img03.jpg',
					'title'           => esc_html__( 'Industry Analysis', 'spintech-pro' ),
					'subtitle'         => esc_html__( 'Marketing & Strategy', 'spintech-pro' ),
					'text'            => esc_html__( 'There are many variations of passages of Lorem Ipsum available but the majority have suffered injected humour dummy now.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Purchase Now', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'button_second'	  =>  esc_html__( 'Learn More', 'spintech-pro' ),
					'link2'	  =>  esc_html__( '#', 'spintech-pro' ),
					'btn3'	  =>  esc_html__( 'Watch Video', 'spintech-pro' ),
					"slide_align" => "right", 
					'id'              => 'customizer_repeater_slider_003',
			
				),
			)
		)
	);
}


/*
 *
 * Info Default
 */
 function spintech_get_info_default() {
	return apply_filters(
		'spintech_get_info_default', json_encode(
				 array(
				array(
					'title'           => esc_html__( 'Expert Work', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur.', 'spintech-pro' ),
					'icon_value'       => 'fa-user',
					'id'              => 'customizer_repeater_info_001',
					
				),
				array(
					'title'           => esc_html__( '24/7 Support', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur.', 'spintech-pro' ),
					'icon_value'       => 'fa-headphones',
					'id'              => 'customizer_repeater_info_002',				
				),
				array(
					'title'           => esc_html__( 'Creative Design', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur.', 'spintech-pro' ),
					'icon_value'       => 'fa-edit',
					'id'              => 'customizer_repeater_info_003',
				),
				array(
					'title'           => esc_html__( 'Well Experienced', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur.', 'spintech-pro' ),
					'icon_value'       => 'fa-trophy',
					'id'              => 'customizer_repeater_info_004',
				),
			)
		)
	);
}



/*
 *
 * Service Default
 */
 function spintech_get_service_default() {
	return apply_filters(
		'spintech_get_service_default', json_encode(
				 array(
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img01.png',
					'title'           => esc_html__( 'Web Development', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_service_001',
					
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img02.png',
					'title'           => esc_html__( 'Database Analysis', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_service_002',				
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img03.png',
					'title'           => esc_html__( 'Server Security', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_service_003',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img04.png',
					'title'           => esc_html__( 'Web Development', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_service_004',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img05.png',
					'title'           => esc_html__( 'Database Analysis', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_service_005',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img06.png',
					'title'           => esc_html__( 'Server Security', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_service_006',
				),
			)
		)
	);
}


/*
 *
 * Design & Develpement Default
 */
 function spintech_get_design_default() {
	return apply_filters(
		'spintech_get_design_default', json_encode(
				 array(
				array(
					'icon_value'       => 'fa-bar-chart',
					'title'           => esc_html__( 'Flexible Office ', 'spintech-pro' ),
					'id'              => 'customizer_repeater_design_001',
					
				),
				array(
					'icon_value'       => 'fa-search',
					'title'           => esc_html__( 'Macbook Pro', 'spintech-pro' ),
					'id'              => 'customizer_repeater_design_002',				
				),
				array(
					'icon_value'       => 'fa-life-ring',
					'title'           => esc_html__( 'Training & Support', 'spintech-pro' ),
					'id'              => 'customizer_repeater_design_003',
				),
				array(
					'icon_value'       => 'fa-umbrella',
					'title'           => esc_html__( 'Generous Holidays', 'spintech-pro' ),
					'id'              => 'customizer_repeater_design_004',
				),
				array(
					'icon_value'       => 'fa-coffee',
					'title'           => esc_html__( 'Friday Teatime', 'spintech-pro' ),
					'id'              => 'customizer_repeater_design_005',
				),
				array(
					'icon_value'       => 'fa-th',
					'title'           => esc_html__( 'Well Stocked Fridge', 'spintech-pro' ),
					'id'              => 'customizer_repeater_design_006',
				),
				array(
					'icon_value'       => 'fa-paint-brush',
					'title'           => esc_html__( 'Design & Branding', 'spintech-pro' ),
					'id'              => 'customizer_repeater_design_007',
				),
				array(
					'icon_value'       => 'fa-truck',
					'title'           => esc_html__( 'More Stuff', 'spintech-pro' ),
					'id'              => 'customizer_repeater_design_008',
				),
				array(
					'icon_value'       => 'fa-calendar',
					'title'           => esc_html__( 'Resource Planning', 'spintech-pro' ),
					'id'              => 'customizer_repeater_design_009',
				),
				array(
					'icon_value'       => 'fa-headphones',
					'title'           => esc_html__( 'Live Support', 'spintech-pro' ),
					'id'              => 'customizer_repeater_design_0010',
				),
			)
		)
	);
}




/*
 *
 * Team Default
 */
 function spintech_get_team_default() {
	return apply_filters(
		'spintech_get_team_default', json_encode(
					  array(
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/team/img01.jpg',
					'title'           => esc_html__( 'Jack Semper ', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Support','spintech-pro' ),
					'id'              => 'customizer_repeater_team_0001',
					'social_repeater' => json_encode(
						array(
							array(
								'id'   => 'customizer-repeater-social-repeater-team_001',
								'link' => 'facebook.com',
								'icon' => 'fa-facebook',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_003',
								'link' => 'twitter.com',
								'icon' => 'fa-twitter',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_004',
								'link' => 'instagram.com',
								'icon' => 'fa-instagram',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_005',
								'link' => 'linkedin.com',
								'icon' => 'fa-linkedin',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_006',
								'link' => 'behance.com',
								'icon' => 'fa-behance',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_007',
								'link' => 'vimeo.com',
								'icon' => 'fa-vimeo',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_008',
								'link' => 'skype.com',
								'icon' => 'fa-skype',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_009',
								'link' => 'pinterest.com',
								'icon' => 'fa-pinterest',
							),
						)
					),
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/team/img02.jpg',
					'title'           => esc_html__( 'Avano Morgan', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Management', 'spintech-pro' ),
					'id'              => 'customizer_repeater_team_0002',
					'social_repeater' => json_encode(
						array(
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0011',
								'link' => 'facebook.com',
								'icon' => 'fa-facebook',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0012',
								'link' => 'twitter.com',
								'icon' => 'fa-twitter',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0013',
								'link' => 'pinterest.com',
								'icon' => 'fa-instagram',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0014',
								'link' => 'linkedin.com',
								'icon' => 'fa-linkedin',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0015',
								'link' => 'behance.com',
								'icon' => 'fa-behance',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0016',
								'link' => 'vimeo.com',
								'icon' => 'fa-vimeo',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0017',
								'link' => 'skype.com',
								'icon' => 'fa-skype',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0018',
								'link' => 'pinterest.com',
								'icon' => 'fa-pinterest',
							),
						)
					),
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/team/img03.jpg',
					'title'           => esc_html__( 'Philip Wilson', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Marketing', 'spintech-pro' ),
					'id'              => 'customizer_repeater_team_0003',
					'social_repeater' => json_encode(
						array(
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0021',
								'link' => 'facebook.com',
								'icon' => 'fa-facebook',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0022',
								'link' => 'twitter.com',
								'icon' => 'fa-twitter',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0023',
								'link' => 'linkedin.com',
								'icon' => 'fa-instagram',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0024',
								'link' => 'linkedin.com',
								'icon' => 'fa-linkedin',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0025',
								'link' => 'behance.com',
								'icon' => 'fa-behance',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0026',
								'link' => 'vimeo.com',
								'icon' => 'fa-vimeo',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0027',
								'link' => 'skype.com',
								'icon' => 'fa-skype',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0028',
								'link' => 'pinterest.com',
								'icon' => 'fa-pinterest',
							),
						)
					),
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/team/img04.jpg',
					'title'           => esc_html__( 'Amanda Richards', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Founder', 'spintech-pro' ),
					'id'              => 'customizer_repeater_team_0004',
					'social_repeater' => json_encode(
						array(
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0031',
								'link' => 'facebook.com',
								'icon' => 'fa-facebook',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0032',
								'link' => 'twitter.com',
								'icon' => 'fa-twitter',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0033',
								'link' => 'linkedin.com',
								'icon' => 'fa-instagram',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0034',
								'link' => 'linkedin.com',
								'icon' => 'fa-linkedin',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0035',
								'link' => 'behance.com',
								'icon' => 'fa-behance',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0036',
								'link' => 'vimeo.com',
								'icon' => 'fa-vimeo',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0037',
								'link' => 'skype.com',
								'icon' => 'fa-skype',
							),
							array(
								'id'   => 'customizer-repeater-social-repeater-team_0038',
								'link' => 'pinterest.com',
								'icon' => 'fa-pinterest',
							),
						)
					),
				),
			)
		)
	);
}



/*
 *
 * Gallery Default
 */
 function spintech_get_gallery_default() {
	return apply_filters(
		'spintech_get_gallery_default', json_encode(
				 array(
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/gallery/img01.jpg',
					'title'           => esc_html__( 'Some Dummy Text Here.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_gallery_001',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/gallery/img02.jpg',
					'title'           => esc_html__( 'Some Dummy Text Here.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_gallery_002',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/gallery/img03.jpg',
					'title'           => esc_html__( 'Some Dummy Text Here.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_gallery_003',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/gallery/img04.jpg',
					'title'           => esc_html__( 'Some Dummy Text Here.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_gallery_004',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/gallery/img05.jpg',
					'title'           => esc_html__( 'Some Dummy Text Here.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_gallery_005',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/gallery/img06.jpg',
					'title'           => esc_html__( 'Some Dummy Text Here.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_gallery_006',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/gallery/img07.jpg',
					'title'           => esc_html__( 'Some Dummy Text Here.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_gallery_007',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/gallery/img08.jpg',
					'title'           => esc_html__( 'Some Dummy Text Here.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_gallery_008',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/gallery/img09.jpg',
					'title'           => esc_html__( 'Some Dummy Text Here.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_gallery_009',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/gallery/img10.jpg',
					'title'           => esc_html__( 'Some Dummy Text Here.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_gallery_010',
				),
			)
		)
	);
}




/*
 *
 * Funfact Default
 */
 function spintech_get_funfact_default() {
	return apply_filters(
		'spintech_get_funfact_default', json_encode(
				 array(
				array(
					'title'           => esc_html__( '254', 'spintech-pro' ),
					'subtitle'           => esc_html__( '+', 'spintech-pro' ),
					'text'            => esc_html__( 'Expert Consultants', 'spintech-pro' ),
					'image_url'       => get_template_directory_uri() . '/assets/images/funfact/img01.png',
					'id'              => 'customizer_repeater_funfact_001',
					
				),
				array(
					'title'           => esc_html__( '807', 'spintech-pro' ),
					'subtitle'           => esc_html__( '+', 'spintech-pro' ),
					'text'            => esc_html__( 'Development Hours', 'spintech-pro' ),
					'image_url'       => get_template_directory_uri() . '/assets/images/funfact/img02.png',
					'id'              => 'customizer_repeater_funfact_002',			
				),
				array(
					'title'           => esc_html__( '926', 'spintech-pro' ),
					'subtitle'           => esc_html__( '+', 'spintech-pro' ),
					'text'            => esc_html__( 'Trusted Clients', 'spintech-pro' ),
					'image_url'       => get_template_directory_uri() . '/assets/images/funfact/img03.png',
					'id'              => 'customizer_repeater_funfact_003',
				),
				array(
					'title'           => esc_html__( '543', 'spintech-pro' ),
					'subtitle'           => esc_html__( '+', 'spintech-pro' ),
					'text'            => esc_html__( 'Projects Delivered', 'spintech-pro' ),
					'image_url'       => get_template_directory_uri() . '/assets/images/funfact/img04.png',
					'id'              => 'customizer_repeater_funfact_004',
				)
			)
		)
	);
}



/*
 *
 * Testimonial Default
 */
 
 function spintech_get_testimonial_default() {
	return apply_filters(
		'spintech_get_testimonial_default', json_encode(
			array(
				array(
					'title'           => esc_html__( 'Julia Corner', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'CEO', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, Connect adipisicing elit, sed do tempor et aliqua.', 'spintech-pro' ),
					'image_url'		  =>  get_template_directory_uri() . '/assets/images/testimonials/img01.png',
					'id'              => 'customizer_repeater_testimonial_001',
				),
				array(
					'title'           => esc_html__( 'Rizon Pet', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Founder', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, Connect adipisicing elit, sed do tempor et aliqua.', 'spintech-pro' ),
					'image_url'		  =>  get_template_directory_uri() . '/assets/images/testimonials/img02.png',
					'id'              => 'customizer_repeater_testimonial_002',
				),
				array(
					'title'           => esc_html__( 'Miekel Stark', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Designer', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, Connect adipisicing elit, sed do tempor et aliqua.', 'spintech-pro' ),
					'image_url'		  =>  get_template_directory_uri() . '/assets/images/testimonials/img03.png',
					'id'              => 'customizer_repeater_testimonial_003',
				),
				array(
					'title'           => esc_html__( 'West Corner', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'PPO', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, Connect adipisicing elit, sed do tempor et aliqua.', 'spintech-pro' ),
					'image_url'		  =>  get_template_directory_uri() . '/assets/images/testimonials/img04.png',
					'id'              => 'customizer_repeater_testimonial_004',
				),
		    )
		)
	);
}






/*
 *
 * Steps Default
 */
 
 function spintech_get_steps_default() {
	return apply_filters(
		'spintech_get_steps_default', json_encode(
			array(
				array(
					'title'           => esc_html__( '01', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Research', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, elit, sed to  do etc.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_steps_001',
				),
				array(
					'title'           => esc_html__( '02', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Targeting', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, elit, sed to  do etc.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_steps_002',
				),
				array(
					'title'           => esc_html__( '03', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Results', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, elit, sed to  do etc.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_steps_003',
				),
		    )
		)
	);
}



/*
 *
 * Journey Default
 */
 
 function spintech_get_journey_default() {
	return apply_filters(
		'spintech_get_journey_default', json_encode(
			array(
				array(
					'title'           => esc_html__( '2020', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Projesct Idea', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod etc.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_journey_001',
				),
				array(
					'title'           => esc_html__( '2019', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Business Conception', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod etc.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_journey_002',
				),
				array(
					'title'           => esc_html__( '2018', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Legel Review', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod etc.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_journey_003',
				),
				array(
					'title'           => esc_html__( '2017', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Infrastucture Design', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod etc.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_journey_004',
				),
				array(
					'title'           => esc_html__( '2016', 'spintech-pro' ),
					'subtitle'        => esc_html__( 'Company Stablished', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod etc.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_journey_005',
				),
		    )
		)
	);
}



/*
 *
 * :Page Service Default
 */
 function spintech_get_pg_service_default() {
	return apply_filters(
		'spintech_get_pg_service_default', json_encode(
				 array(
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img01.png',
					'title'           => esc_html__( 'Web Development', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_service_001',
					
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img02.png',
					'title'           => esc_html__( 'Database Analysis', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_service_002',				
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img03.png',
					'title'           => esc_html__( 'Server Security', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_service_003',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img04.png',
					'title'           => esc_html__( 'Web Development', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_service_004',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img05.png',
					'title'           => esc_html__( 'Database Analysis', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_service_005',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img06.png',
					'title'           => esc_html__( 'Server Security', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_service_006',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img01.png',
					'title'           => esc_html__( 'Web Development', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_service_007',
					
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img02.png',
					'title'           => esc_html__( 'Database Analysis', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_service_008',				
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img03.png',
					'title'           => esc_html__( 'Server Security', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_service_009',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img04.png',
					'title'           => esc_html__( 'Web Development', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_service_0010',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img05.png',
					'title'           => esc_html__( 'Database Analysis', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_service_0011',
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/services/img06.png',
					'title'           => esc_html__( 'Server Security', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Read More', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_service_0012',
				),
			)
		)
	);
}




/*
 *
 * Contact Default
 */
 function spintech_get_ct_adress_default() {
	return apply_filters(
		'spintech_get_ct_adress_default', json_encode(
				 array(
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/support/symbol01.png',
					'title'           => esc_html__( 'USA Office', 'spintech-pro' ),
					'text'            => esc_html__( '66 McKenzie Turnpike Apt. 745, San Francisco', 'spintech-pro' ),
					'id'              => 'customizer_repeater_ct_adress_001',
					
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/support/symbol02.png',
					'title'           => esc_html__( 'France Office', 'spintech-pro' ),
					'text'            => esc_html__( '58 rue Nationale, Île-de-France Paris 75007', 'spintech-pro' ),
					'id'              => 'customizer_repeater_ct_adress_002',				
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/support/symbol03.png',
					'title'           => esc_html__( 'Thailand Office', 'spintech-pro' ),
					'text'            => esc_html__( '45 Ratchada Rd, Huai Khwang, Bangkok 10310', 'spintech-pro' ),
					'id'              => 'customizer_repeater_ct_adress_003',
				),
			)
		)
	);
}




/*
 *
 * Contact Info Default
 */
 function spintech_get_ct_info_default() {
	return apply_filters(
		'spintech_get_ct_info_default', json_encode(
				 array(
				array(
					'icon_value'       => 'fa-home',
					'title'           => esc_html__( 'Our Head Office', 'spintech-pro' ),
					'text'            => esc_html__( '2130 Fulton Street San Diego, CA 94117 - 1080 USA', 'spintech-pro' ),
					'id'              => 'customizer_repeater_ct_info_001',
					
				),
				array(
					'icon_value'       => 'fa-envelope',
					'title'           => esc_html__( 'E-mail', 'spintech-pro' ),
					'text'            => esc_html__( 'Info@example.com, ', 'spintech-pro' ),
					'id'              => 'customizer_repeater_ct_info_002',				
				),
				array(
					'icon_value'       => 'fa-phone',
					'title'           => esc_html__( 'Phone', 'spintech-pro' ),
					'text'            => esc_html__( '70 975 975 70', 'spintech-pro' ),
					'id'              => 'customizer_repeater_ct_info_003',
				),
			)
		)
	);
}



/*
 *
 * Company Benefit Default
 */
 function spintech_get_company_benefit_default() {
	return apply_filters(
		'spintech_get_company_benefit_default', json_encode(
				 array(
				array(
					'icon_value'       => 'fa-briefcase',
					'title'           => esc_html__( 'Health Care', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, adipisicing elit, sed do etc.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_company_benefit_001',
					
				),
				array(
					'icon_value'       => 'fa-star',
					'title'           => esc_html__( 'Flexibility', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, adipisicing elit, sed do etc., ', 'spintech-pro' ),
					'id'              => 'customizer_repeater_company_benefit_002',				
				),
				array(
					'icon_value'       => 'fa-gift',
					'title'           => esc_html__( 'Gift', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, adipisicing elit, sed do etc.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_company_benefit_003',
				),
				array(
					'icon_value'       => 'fa-toggle-on',
					'title'           => esc_html__( 'Fun', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, adipisicing elit, sed do etc.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_company_benefit_004',
				),
				array(
					'icon_value'       => 'fa-headphones',
					'title'           => esc_html__( 'Lifestyle', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, adipisicing elit, sed do etc.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_company_benefit_004',
				),
			)
		)
	);
}





/*
 *
 * Location Default
 */
 function spintech_get_com_location_default() {
	return apply_filters(
		'spintech_get_com_location_default', json_encode(
				 array(
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/locations/img01.png',
					'title'           => esc_html__( 'United States', 'spintech-pro' ),
					'text'            => esc_html__( '22 Road, Brokleen Street, NY, USA', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Help Center', 'spintech-pro' ),
					'id'              => 'customizer_repeater_com_loc_001',
					
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/locations/img02.png',
					'title'           => esc_html__( 'Germany', 'spintech-pro' ),
					'text'            => esc_html__( '32 Dora Creek,Tuntable Creek, Germany', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Help Center', 'spintech-pro' ),
					'id'              => 'customizer_repeater_com_loc_002',				
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/locations/img03.png',
					'title'           => esc_html__( 'Russia', 'spintech-pro' ),
					'text'            => esc_html__( '1240 Park, Avenues Mall Street, Russia', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Help Center', 'spintech-pro' ),
					'id'              => 'customizer_repeater_com_loc_003',
				)
			)
		)
	);
}




/*
 *
 * Support Default
 */
 function spintech_get_com_support_default() {
	return apply_filters(
		'spintech_get_com_support_default', json_encode(
				 array(
				array(
					'icon_value'       => 'fa-envelope',
					'title'           => esc_html__( 'E-Mail Support', 'spintech-pro' ),
					'id'              => 'customizer_repeater_com_support_001',
					
				),
				array(
					'icon_value'       => 'fa-comments',
					'title'           => esc_html__( 'Voice Chat', 'spintech-pro' ),
					'id'              => 'customizer_repeater_com_support_002',			
				),
				array(
					'icon_value'       => 'fa-phone',
					'title'           => esc_html__( 'Phone', 'spintech-pro' ),
					'id'              => 'customizer_repeater_com_support_003',
				),
				array(
					'icon_value'       => 'fa-desktop',
					'title'           => esc_html__( 'Remote Chat', 'spintech-pro' ),
					'id'              => 'customizer_repeater_com_support_004',
					
				),
				array(
					'icon_value'       => 'fa-file',
					'title'           => esc_html__( 'Forum', 'spintech-pro' ),
					'id'              => 'customizer_repeater_com_support_005',			
				),
				array(
					'icon_value'       => 'fa-file-archive-o',
					'title'           => esc_html__( 'K-base', 'spintech-pro' ),
					'id'              => 'customizer_repeater_com_support_006',
				),
			)
		)
	);
}




/*
 *
 * Support Care  Default
 */
 function spintech_get_com_support_care_default() {
	return apply_filters(
		'spintech_get_com_support_care_default', json_encode(
				 array(
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/support/img01.png',
					'title'           => esc_html__( 'Knowledge Base', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'View All', 'spintech-pro' ),
					'id'              => 'customizer_repeater_com_sup_care_001',
					
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/support/img02.png',
					'title'           => esc_html__( 'Support Forum', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'Join Our Form', 'spintech-pro' ),
					'id'              => 'customizer_repeater_com_sup_care_002',				
				),
				array(
					'image_url'       => get_template_directory_uri() . '/assets/images/support/img03.png',
					'title'           => esc_html__( 'FAQ', 'spintech-pro' ),
					'text'            => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do etc.', 'spintech-pro' ),
					'text2'	  =>  esc_html__( 'View All', 'spintech-pro' ),
					'id'              => 'customizer_repeater_com_sup_care_003',
				)
			)
		)
	);
}


/*
 *
 * Social Icon
 */
function spintech_get_comming_soon_social_icon_default() {
	return apply_filters(
		'spintech_get_comming_soon_social_icon_default', json_encode(
				 array(
				array(
					'icon_value'	  =>  esc_html__( 'fa-facebook', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_commingsoon_social_001',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-google-plus', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_commingsoon_social_002',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-twitter', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_commingsoon_social_003',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-linkedin', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_commingsoon_social_004',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-behance', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_commingsoon_social_005',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-vimeo', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_commingsoon_social_006',
				),
				array(
					'icon_value'	  =>  esc_html__( 'fa-skype', 'spintech-pro' ),
					'link'	  =>  esc_html__( '#', 'spintech-pro' ),
					'id'              => 'customizer_repeater_commingsoon_social_007',
				),
			)
		)
	);
}





/*
 *
 * FAQ  Default
 */
 function spintech_get_pg_faq_default() {
	return apply_filters(
		'spintech_get_pg_faq_default', json_encode(
				 array(
				array(
					'title'           => esc_html__( 'Are Free Anti-Virus Software any Good?', 'spintech-pro' ),
					'text'            => esc_html__( 'First and foremost, you never want to go without security protection on your computer. Free Anti-Virus has very low detection rates. Give us a call and we will be happy to inform yo to all our clients for Spyware.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_faq_001',
					
				),
				array(
					'title'           => esc_html__( 'What exactly are Managed IT Services?', 'spintech-pro' ),
					'text'            => esc_html__( 'First and foremost, you never want to go without security protection on your computer. Free Anti-Virus has very low detection rates. Give us a call and we will be happy to inform yo to all our clients for Spyware.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_faq_002',				
				),
				array(
					'title'           => esc_html__( 'What is cloud Backup?', 'spintech-pro' ),
					'text'            => esc_html__( 'First and foremost, you never want to go without security protection on your computer. Free Anti-Virus has very low detection rates. Give us a call and we will be happy to inform yo to all our clients for Spyware.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_faq_003',
				),
				array(
					'title'           => esc_html__( 'What Kind of response time can I expect?', 'spintech-pro' ),
					'text'            => esc_html__( 'First and foremost, you never want to go without security protection on your computer. Free Anti-Virus has very low detection rates. Give us a call and we will be happy to inform yo to all our clients for Spyware.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_faq_004',
				),
				array(
					'title'           => esc_html__( 'How long is a Managed Services Contact For?', 'spintech-pro' ),
					'text'            => esc_html__( 'First and foremost, you never want to go without security protection on your computer. Free Anti-Virus has very low detection rates. Give us a call and we will be happy to inform yo to all our clients for Spyware.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_faq_005',
				),
				array(
					'title'           => esc_html__( 'What should I do before I call for help ?', 'spintech-pro' ),
					'text'            => esc_html__( 'First and foremost, you never want to go without security protection on your computer. Free Anti-Virus has very low detection rates. Give us a call and we will be happy to inform yo to all our clients for Spyware.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_faq_006',
				),
				array(
					'title'           => esc_html__( 'What does having Managed IT Services cost ?', 'spintech-pro' ),
					'text'            => esc_html__( 'First and foremost, you never want to go without security protection on your computer. Free Anti-Virus has very low detection rates. Give us a call and we will be happy to inform yo to all our clients for Spyware.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_faq_007',
				),
				array(
					'title'           => esc_html__( 'What if we already have an internal IT Department ?', 'spintech-pro' ),
					'text'            => esc_html__( 'First and foremost, you never want to go without security protection on your computer. Free Anti-Virus has very low detection rates. Give us a call and we will be happy to inform yo to all our clients for Spyware.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_faq_008',
				),
				array(
					'title'           => esc_html__( 'How does a flat rate billing save me money ?', 'spintech-pro' ),
					'text'            => esc_html__( 'First and foremost, you never want to go without security protection on your computer. Free Anti-Virus has very low detection rates. Give us a call and we will be happy to inform yo to all our clients for Spyware.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_faq_009',
				),
				array(
					'title'           => esc_html__( 'What types of systems do you support ?', 'spintech-pro' ),
					'text'            => esc_html__( 'First and foremost, you never want to go without security protection on your computer. Free Anti-Virus has very low detection rates. Give us a call and we will be happy to inform yo to all our clients for Spyware.', 'spintech-pro' ),
					'id'              => 'customizer_repeater_pg_faq_0010',
				),
			)
		)
	);
}