<?php
/**
 * WPML and Polylang compatibility functions.
 *
 * @package spintech-pro
 * @since 1.0
 */

/**
 * Filter to translate strings
 */
function spintech_translate_single_string( $original_value, $domain ) {
	if ( is_customize_preview() ) {
		$wpml_translation = $original_value;
	} else {
		$wpml_translation = apply_filters( 'wpml_translate_single_string', $original_value, $domain, $original_value );
		if ( $wpml_translation === $original_value && function_exists( 'pll__' ) ) {
			return pll__( $original_value );
		}
	}
	return $wpml_translation;
}
add_filter( 'spintech_translate_single_string', 'spintech_translate_single_string', 10, 2 );

/**
 * Helper to register pll string.
 *
 * @param String    $theme_mod Theme mod name.
 * @param bool/json $default Default value.
 * @param String    $name Name for polylang backend.
 */
function spintech_pll_string_register_helper( $theme_mod, $default, $name ) {
	if ( ! function_exists( 'pll_register_string' ) ) {
		return;
	}

	$repeater_content = get_theme_mod( $theme_mod, $default );
	$repeater_content = json_decode( $repeater_content );
	if ( ! empty( $repeater_content ) ) {
		foreach ( $repeater_content as $repeater_item ) {
			foreach ( $repeater_item as $field_name => $field_value ) {
				if ( $field_value !== 'undefined' ) {
					if ( $field_name === 'social_repeater' ) {
						$social_repeater_value = json_decode( $field_value );
						if ( ! empty( $social_repeater_value ) ) {
							foreach ( $social_repeater_value as $social ) {
								foreach ( $social as $key => $value ) {
									if ( $key === 'link' ) {
										pll_register_string( 'Social link', $value, $name );
									}
									if ( $key === 'icon' ) {
										pll_register_string( 'Social icon', $value, $name );
									}
								}
							}
						}
					} else {
						if ( $field_name !== 'id' ) {
							$f_n = ucfirst( $field_name );
							pll_register_string( $f_n, $field_value, $name );
						}
					}
				}
			}
		}
	}
}

/**
 * Header Social. Register strings for translations.
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_header_social_register_strings() {
	$default = spintech_get_social_icon_default();
	spintech_pll_string_register_helper( 'social_icons', $default, 'Header section' );
}

/**
 * Slider
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_slider_register_strings() {
	$default = spintech_get_slider_default();
	spintech_pll_string_register_helper( 'slider', $default, 'Slider section' );
}

/**
 * Info
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_info_register_strings() {
	$default = spintech_get_info_default();
	spintech_pll_string_register_helper( 'info_contents', $default, 'Info section' );
}


/**
 * Service
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_service_register_strings() {
	$default = spintech_get_service_default();
	spintech_pll_string_register_helper( 'service_contents', $default, 'Service section' );
}

/**
 * Design
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_design_register_strings() {
	$default = spintech_get_design_default();
	spintech_pll_string_register_helper( 'design_contents', $default, 'Design section' );
}

/**
 * Team
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_team_register_strings() {
	$default = spintech_get_team_default();
	spintech_pll_string_register_helper( 'team_contents', $default, 'Team section' );
}


/**
 * Gallery
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_gallery_register_strings() {
	$default = spintech_get_gallery_default();
	spintech_pll_string_register_helper( 'gallery', $default, 'Gallery section' );
}


/**
 * Funfact
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_funfact_register_strings() {
	$default = spintech_get_funfact_default();
	spintech_pll_string_register_helper( 'funfact_contents', $default, 'Funfact section' );
}

/**
 * Testimonial
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_testimonial_register_strings() {
	$default = spintech_get_testimonial_default();
	spintech_pll_string_register_helper( 'testimonials', $default, 'Testimonial section' );
}


/**
 * Steps
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_steps_register_strings() {
	$default = spintech_get_steps_default();
	spintech_pll_string_register_helper( 'abt_steps_contents', $default, 'Step section' );
}


/**
 * Journey
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_journey_register_strings() {
	$default = spintech_get_journey_default();
	spintech_pll_string_register_helper( 'abt_journey_contents', $default, 'Journey section' );
}


/**
 * Page Service
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_pg_service_register_strings() {
	$default = spintech_get_pg_service_default();
	spintech_pll_string_register_helper( 'service_pg_contents', $default, 'Page Service section' );
}


/**
 * Page Gallery
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_pg_gallery_register_strings() {
	$default = spintech_get_gallery_default();
	spintech_pll_string_register_helper( 'gallery_pg', $default, 'Page Gallery section' );
}

/**
 * Page Contact Address
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_pg_contact_address_register_strings() {
	$default = spintech_get_ct_adress_default();
	spintech_pll_string_register_helper( 'ct_adress_contents', $default, 'Contact Address section' );
}


/**
 * Page Contact Info
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_pg_contact_info_register_strings() {
	$default = spintech_get_ct_info_default();
	spintech_pll_string_register_helper( 'ct_info_contents', $default, 'Contact Info section' );
}


/**
 * Benefit
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_benefit_register_strings() {
	$default = spintech_get_company_benefit_default();
	spintech_pll_string_register_helper( 'company_benefit_contents', $default, 'Benefit section' );
}


/**
 * Location
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_location_register_strings() {
	$default = spintech_get_com_location_default();
	spintech_pll_string_register_helper( 'company_loc_contents', $default, 'Location section' );
}

/**
 * Support
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_support_register_strings() {
	$default = spintech_get_com_support_default();
	spintech_pll_string_register_helper( 'company_support_contents', $default, 'Support section' );
}

/**
 * Support Care
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_support_care_register_strings() {
	$default = spintech_get_com_support_care_default();
	spintech_pll_string_register_helper( 'company_support_care_contents', $default, 'Support Care section' );
}


/**
 * Support Care
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_comming_soon_social_register_strings() {
	$default = spintech_get_comming_soon_social_icon_default();
	spintech_pll_string_register_helper( 'comming_soon_social_icons', $default, 'Comming Soon Social section' );
}

/**
 * Footer Social
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_footer_social_register_strings() {
	$default = spintech_get_footer_social_icon_default();
	spintech_pll_string_register_helper( 'footer_social_content', $default, 'Footer Social section' );
}


/**
 * Footer Info
 *
 * @modified 1.0
 * @access public
 */
 
function spintech_footer_info_register_strings() {
	$default = spintech_get_foot_info_default();
	spintech_pll_string_register_helper( 'footer_ct_info_content', $default, 'Footer Info section' );
}



if ( function_exists( 'pll_register_string' ) ) {
	add_action( 'after_setup_theme', 'spintech_header_social_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_slider_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_info_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_service_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_design_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_team_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_gallery_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_funfact_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_testimonial_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_steps_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_journey_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_pg_service_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_pg_gallery_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_pg_contact_address_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_pg_contact_info_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_benefit_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_location_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_support_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_support_care_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_comming_soon_social_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_footer_social_register_strings', 11 );
	add_action( 'after_setup_theme', 'spintech_footer_info_register_strings', 11 );
}


